@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -26,10 +26,9 @@ bool LineEditCatchReturnKey::eventFilter(QObject *obj, QEvent *event)
 {
     if (obj == mLineEdit) {
         if (event->type() == QEvent::KeyPress) {
-            auto *e = static_cast<QKeyEvent *>(event);
+            auto e = static_cast<QKeyEvent *>(event);
             if (e->key() == Qt::Key_Return || e->key() == Qt::Key_Enter) {
-                const bool stopEvent = (e->modifiers() == Qt::NoButton ||
-                                        e->modifiers() == Qt::KeypadModifier);
+                const bool stopEvent = (e->modifiers() == Qt::NoButton || e->modifiers() == Qt::KeypadModifier);
                 if (stopEvent) {
                     Q_EMIT mLineEdit->returnPressed();
                 }
