@@ -1,25 +1,12 @@
 /*
-    Copyright (C) 2010 Casey Link <unnamedrambler@gmail.com>
-    Copyright (C) 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+    SPDX-FileCopyrightText: 2010 Casey Link <unnamedrambler@gmail.com>
+    SPDX-FileCopyrightText: 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
 
     Refactored from earlier code by:
-    Copyright (c) 2010 Volker Krause <vkrause@kde.org>
-    Copyright (c) 2004 Cornelius Schumacher <schumacher@kde.org>
+    SPDX-FileCopyrightText: 2010 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2004 Cornelius Schumacher <schumacher@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "multiplyinglineeditor.h"
@@ -29,22 +16,19 @@
 using namespace KPIM;
 MultiplyingLineEditor::MultiplyingLineEditor(MultiplyingLineFactory *factory, QWidget *parent)
     : QWidget(parent)
-    , mModified(false)
     , mMultiplyingLineFactory(factory)
 {
-    QBoxLayout *topLayout = new QHBoxLayout(this);
+    auto topLayout = new QHBoxLayout(this);
     topLayout->setContentsMargins(0, 0, 0, 0);
 
     mView = new MultiplyingLineView(mMultiplyingLineFactory, this);
     topLayout->addWidget(mView);
     connect(mView, &MultiplyingLineView::focusUp, this, &MultiplyingLineEditor::focusUp);
     connect(mView, &MultiplyingLineView::focusDown, this, &MultiplyingLineEditor::focusDown);
-    connect(mView, &MultiplyingLineView::completionModeChanged,
-            this, &MultiplyingLineEditor::completionModeChanged);
+    connect(mView, &MultiplyingLineView::completionModeChanged, this, &MultiplyingLineEditor::completionModeChanged);
     connect(mView, &MultiplyingLineView::lineDeleted, this, &MultiplyingLineEditor::lineDeleted);
     connect(mView, &MultiplyingLineView::lineAdded, this, &MultiplyingLineEditor::lineAdded);
-    connect(mView, &MultiplyingLineView::sizeHintChanged,
-            this, &MultiplyingLineEditor::sizeHintChanged);
+    connect(mView, &MultiplyingLineView::sizeHintChanged, this, &MultiplyingLineEditor::sizeHintChanged);
 }
 
 MultiplyingLineEditor::~MultiplyingLineEditor()
@@ -52,12 +36,12 @@ MultiplyingLineEditor::~MultiplyingLineEditor()
     delete mMultiplyingLineFactory;
 }
 
-bool MultiplyingLineEditor::addData(const MultiplyingLineData::Ptr &data)
+bool MultiplyingLineEditor::addData(const MultiplyingLineData::Ptr &data, bool showDialogBox)
 {
     MultiplyingLine *line = mView->emptyLine();
     bool tooManyAddress = false;
     if (!line) {
-        line = mView->addLine();
+        line = mView->addLine(showDialogBox);
     }
     if (!line) {
         tooManyAddress = true;
@@ -122,7 +106,7 @@ MultiplyingLineFactory *MultiplyingLineEditor::factory() const
     return mMultiplyingLineFactory;
 }
 
-QList< MultiplyingLineData::Ptr > MultiplyingLineEditor::allData() const
+QVector<MultiplyingLineData::Ptr> MultiplyingLineEditor::allData() const
 {
     return mView->allData();
 }
@@ -132,7 +116,7 @@ MultiplyingLineData::Ptr MultiplyingLineEditor::activeData() const
     return mView->activeLine()->data();
 }
 
-QList< MultiplyingLine * > MultiplyingLineEditor::lines() const
+QList<MultiplyingLine *> MultiplyingLineEditor::lines() const
 {
     return mView->lines();
 }
