@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef PROGRESSSTATUSBARWIDGETTEST_H
-#define PROGRESSSTATUSBARWIDGETTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,9 +13,8 @@ class ProgressStatusBarWidgetTest : public QObject
     Q_OBJECT
 public:
     explicit ProgressStatusBarWidgetTest(QObject *parent = nullptr);
-    ~ProgressStatusBarWidgetTest() = default;
+    ~ProgressStatusBarWidgetTest() override = default;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
 };
 
-#endif // PROGRESSSTATUSBARWIDGETTEST_H
