@@ -1,25 +1,12 @@
 /*
-   Copyright (C) 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "progressstatusbarwidget.h"
 
-#include "statusbarprogresswidget.h"
 #include "progressdialog.h"
+#include "statusbarprogresswidget.h"
 
 using namespace KPIM;
 class KPIM::ProgressStatusBarWidgetPrivate
@@ -36,7 +23,7 @@ ProgressStatusBarWidget::ProgressStatusBarWidget(QWidget *alignWidget, QWidget *
     : QObject(parent)
     , d(new KPIM::ProgressStatusBarWidgetPrivate)
 {
-    KPIM::ProgressDialog *progressDialog = new KPIM::ProgressDialog(alignWidget, parent);
+    auto progressDialog = new KPIM::ProgressDialog(alignWidget, parent);
     progressDialog->setObjectName(QStringLiteral("progressDialog"));
     progressDialog->setShowTypeProgressItem(showTypeProgressItem);
     progressDialog->hide();
@@ -47,10 +34,7 @@ ProgressStatusBarWidget::ProgressStatusBarWidget(QWidget *alignWidget, QWidget *
     d->mLittleProgress->show();
 }
 
-ProgressStatusBarWidget::~ProgressStatusBarWidget()
-{
-    delete d;
-}
+ProgressStatusBarWidget::~ProgressStatusBarWidget() = default;
 
 KPIM::StatusbarProgressWidget *ProgressStatusBarWidget::littleProgress() const
 {
