@@ -1,37 +1,22 @@
 /*
   This file is part of libkdepim.
 
-  Copyright (c) 2008 Thomas Thrainer <tom_t@gmx.at>
-  Copyright (c) 2010 Bertjan Broeksema <broeksema@kde.org>
+  SPDX-FileCopyrightText: 2008 Thomas Thrainer <tom_t@gmx.at>
+  SPDX-FileCopyrightText: 2010 Bertjan Broeksema <broeksema@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
 */
 
-#ifndef KCHECKCOMBOBOX_H
-#define KCHECKCOMBOBOX_H
+#pragma once
 
 #include "kdepim_export.h"
 
 #include <QComboBox>
 #include <QModelIndex>
 
-namespace KPIM {
+namespace KPIM
+{
 /**
  * A combobox that shows its items in such a way that they can be checked in the
  * drop menu. It provides methods to set the default text when no items are selected
@@ -154,8 +139,8 @@ public:
 
     /**
      * Update the KCheckComboBox text with Item belonging to the role.
-     * @param topLeft Curently unused.
-     * @param bottomRight Curently unused.
+     * @param topLeft Currently unused.
+     * @param bottomRight Currently unused.
      * @param role The role the updated values belong to.
      */
     void updateCheckedItems(const QModelIndex &topLeft = QModelIndex(), const QModelIndex &bottomRight = QModelIndex(), int role = Qt::DisplayRole);
@@ -188,10 +173,9 @@ protected:
 
 private:
     //@cond PRIVATE
-    class Private;
-    Private *const d;
+    class KCheckComboBoxPrivate;
+    std::unique_ptr<KCheckComboBoxPrivate> const d;
     //@endcond
 };
 }
 
-#endif // KCHECKCOMBOBOX_H
